@@ -6,6 +6,7 @@ from ultra_framework.repositories.crud_repository import CRUDRepository
 
 
 class BaseRepositoryFactory(ABC):
+    """BaseRepositoryFactory class"""
 
     repository_map: Mapping[str, Type[CRUDRepository]]
 
@@ -17,7 +18,8 @@ class BaseRepositoryFactory(ABC):
 
     @classmethod
     @abstractmethod
-    def create_factory(cls, session: Session) -> Self: ...
+    def create_factory(cls, session: Session) -> Self:
+        """implement session dependency"""
 
     def get_repository(self, repository_name: str) -> Any:
         return self._repository_dict.get(repository_name, None)
